# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/01_update_project.ipynb (unless otherwise specified).

__all__ = ['update_templates']

# Cell
import os
import pkg_resources

import jinja2
from fastcore.script import *

from kicad_helpers import get_project_root, get_project_metadata, get_gitignore_list, in_gitignore

# Cell
@call_parse
def update_templates():
    # Render all files in the `templates` directory (ignoring anything that is
    # in the `.gitignore` list) as jinja2 templates.
    templates_path = os.path.abspath(pkg_resources.resource_filename('kicad_helpers', 'templates'))
    PROJECT_ROOT = get_project_root()
    metadata = get_project_metadata()

    file_list = []
    for root, dirs, files in os.walk(templates_path):
        if len(files):
            for file in files:
                path = os.path.join(root[len(templates_path) + 1:], file)
                if not in_gitignore(path):
                    src_path = os.path.abspath(os.path.join(templates_path, path))
                    dst_path = os.path.abspath(os.path.join(PROJECT_ROOT, path))

                    # Create the `dst_path` directory if it doesn't exist
                    os.makedirs(os.path.split(dst_path)[0], exist_ok=True)

                    if os.path.exists(dst_path):
                        print(f"{dst_path} already exists")

                    with open(src_path) as f:
                        template = jinja2.Template(f.read())

                    with open(dst_path, "w") as f:
                        f.write(template.render(**metadata))


# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/00_core.ipynb (unless otherwise specified).

__all__ = ['get_project_root', 'PROJECT_ROOT', 'get_project_name', 'get_project_metadata', 'get_gitignore_list',
           'in_gitignore']

# Cell
import glob
import os
import subprocess

import git
from yaml import load, dump
try:
    from yaml import CLoader as Loader, CDumper as Dumper
except ImportError:
    from yaml import Loader, Dumper

# Cell
def get_project_root():
    # Find the current projects' root directory
    git_repo = git.Repo(".", search_parent_directories=True)
    return git_repo.git.rev_parse("--show-toplevel")

# Cell
# Set the PROJECT ROOT environment variable
PROJECT_ROOT = get_project_root()
os.environ["KH_PROJECT_ROOT"] = PROJECT_ROOT
assert(os.getenv("KH_PROJECT_ROOT") == PROJECT_ROOT)

# Cell
def get_project_name():
    # This is based on the name of the KiCad `*.pro` file.
    root = get_project_root()
    return os.path.splitext(os.path.split(glob.glob(os.path.join(root, "*.pro"))[0])[1])[0]

def get_project_metadata():
    PROJECT_ROOT = get_project_root()

    # Default metadata if there's no existing `kicad.yaml` file.
    metadata = {"summary": "A description for your project",
                "site": "https://example.com # A site you would like to link to (include http:// or https://)",
                "color": "black"
    }

    try:
        # If there's an existing `kicad.yaml` file, those settings override the defaults.
        with open(os.path.join(PROJECT_ROOT, "kitspace.yaml")) as f:
            metadata.update({k: v for k, v in load(f, Loader=Loader).items() if k in ["summary", "site", "color"]})
    except FileNotFoundError:
        pass

    # Add the project name
    metadata["project_name"]=get_project_name()
    return metadata

# Cell
def get_gitignore_list():
    PROJECT_ROOT = get_project_root()
    with open(f"{PROJECT_ROOT}/.gitignore") as f:
        gitignore = f.readlines()
    return "|".join([line.strip() for line in gitignore])

# Cell
def in_gitignore(filename):
    try:
        if len(subprocess.check_output(f"echo '{ filename }' | git check-ignore --stdin --no-index", shell=True)):
            return True
    except subprocess.CalledProcessError:
        pass
    return False


# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"get_project_root": "00_core.ipynb",
         "PROJECT_ROOT": "00_core.ipynb",
         "get_project_name": "00_core.ipynb",
         "get_project_metadata": "00_core.ipynb",
         "get_gitignore_list": "00_core.ipynb",
         "in_gitignore": "00_core.ipynb",
         "update_templates": "01_update_project.ipynb"}

modules = ["core.py",
           "update_project.py"]

doc_url = "https://ryanfobel.github.io/kicad_helpers/"

git_url = "https://github.com/ryanfobel/kicad_helpers/tree/main/"

def custom_doc_links(name): return None
